@@ -18,6 +18,7 @@ def show(username, tables):
 		tablename, insert_dict = dropdown_insert_table(
 			tables, {"Recording": tables["Recording"]}, username, headless=True
 		)
+		print(insert_dict)
 
 		# if upstream tables not populated, print error
 		if tablename is None:
@@ -89,6 +90,8 @@ def show(username, tables):
 					st.warning(
 						f"Please read the {equip_type} documentation to see what files are required."
 					)
+					if 'device_channel_mapping' in insert_dict.keys():
+						st.warning("Alternatively your channel mapping file may be incorrect.")
 
 			# otherwise print error
 			else:
@@ -126,7 +129,6 @@ def show(username, tables):
 						# compute statuses
 						if future.done():
 							if future.exception():
-								print(future.exception())
 								status = "upload error"
 							else:
 								status = "upload success"
