@@ -8,6 +8,8 @@ from antelop.utils.datajoint_utils import (
     show_deletes,
     query_to_str,
     delete_status,
+    ids_to_names,
+    names_to_ids,
 )
 from antelop.utils.streamlit_utils import (
     dropdown_query_table,
@@ -21,6 +23,7 @@ import streamlit_antd_components as sac
 
 
 def show(username, tables):
+
     col1, col2, col3 = st.columns([0.2, 0.6, 0.2])
 
     with col2:
@@ -375,6 +378,7 @@ def show(username, tables):
                         st.text("")
 
                         cols = query.proj().heading.names
+                        cols = ids_to_names(cols)
                         to_delete = delete_df[delete_df["delete"] == True][
                             cols
                         ].to_dict(orient="records")
@@ -391,8 +395,14 @@ def show(username, tables):
                             )
                             st.text("")
 
-                        delete_query = query & to_delete
-                        delete_querystring = querystring + f" & {to_delete}"
+                        to_delete_ids = names_to_ids(to_delete, tables)
+                        delete_query = query & to_delete_ids
+                        for key, val in tables.items():
+                            if query.table_name == val.table_name:
+                                delete_table_name = key
+                                break
+                        delete_querystring = f"{delete_table_name} & {str(to_delete_ids)}"
+
 
                         if st.button("Check deletes"):
                             # show cascaded deletes
