@@ -54,11 +54,12 @@ def schema(conn, classes):
     class Recording(classes["manual"]):
         definition = """
         # Recording for this animal
-        -> metadata.Animal
+        -> ProbeInsertion
         -> metadata.Session
         ---
         recording : attach@raw_ephys # Recording folder
         ephys_acquisition: varchar(40) # Equipment type
+        device_channel_mapping = NULL : json # Mapping of device channels to probe channels
         probe_dv_increment : decimal(4, 0) # Probe dorsal-ventral coordinate increment relative to previous session (um)
         recording_deleted = 'False' : enum('False', 'True') # Implements a temporary delete function
         """
@@ -67,7 +68,7 @@ def schema(conn, classes):
     class SpikeSorting(classes["imported"]):
         definition = """
         # Parent table for all curated and populated ephys data
-        -> metadata.Session
+        -> Recording
         -> SortingParams
         ---
         phy : varchar(200) # Tracks phy folders for manual curation
