@@ -24,7 +24,6 @@ import streamlit_antd_components as sac
 from antelop.connection import import_schemas, st_connect
 from antelop.utils.os_utils import get_config, validate_config, get_config_path
 import pymysql
-import streamlit.web.bootstrap
 import os
 
 
@@ -57,9 +56,9 @@ def main():
         st.stop()
 
     if not validate_config(config_file):
-        config_path = get_config_path()
-        os.remove(config_path)
-        st.rerun()
+        st.warning("Config file is not valid. Please check the folders in the config file.")
+        config.show(None, None)
+        st.stop()
 
     # pages to show in app - different for admins
     pages = {
@@ -120,6 +119,9 @@ def main():
             # import schema structure
             tables = import_schemas.schema(conn)
 
+            st.session_state.conn = conn
+            st.session_state.tables = tables
+
             admin = (
                 tables["Experimenter"] & {"experimenter": st.session_state.username}
             ).fetch1("admin") == "True"
