@@ -43,6 +43,7 @@ antelop-python
         cp_st_config()
 
         app = Path(os.path.abspath(__file__)).parent / "app.py"
+        debug_app = Path(os.path.abspath(__file__)).parent / "debug_app.py"
 
         port = find_available_port()
 
@@ -53,5 +54,11 @@ http://localhost:{port}
 """)
 
         with suppress_stdout(not args.debug):
-            sys.argv = ["streamlit", "run", str(app), "--server.port", str(port)]
+            if not args.debug:
+                sys.argv = ["streamlit", "run", str(app), "--server.port", str(port)]
+            else:
+                sys.argv = ["streamlit", "run", str(debug_app), "--server.port", str(port)]
             runpy.run_module("streamlit", run_name="__main__")
+
+if __name__ == '__main__':
+    run()
