@@ -92,33 +92,35 @@ def import_analysis(conn, tables):
                 functions.append(cls(conn))
 
     # user defined analysis functions
-    user_analysis = get_config()["analysis"]["folders"]
-    for folder in user_analysis:
-        scripts = find_script_in_subfolders(folder)
+    config = get_config()
+    if config.get("deployment", {}).get("deployment") == "apptainer" and "analysis" in config:
+        user_analysis = config["analysis"]["folders"]
+        for folder in user_analysis:
+            scripts = find_script_in_subfolders(folder)
 
-        def import_scripts(scripts, base_path=[]):
-            for key, val in scripts.items():
-                if key == ".":
-                    for script in val:
-                        try:
-                            module = import_script(Path(folder) / script)
-                            for _, cls in module.__dict__.items():
-                                if (
-                                    inspect.isclass(cls)
-                                    and issubclass(cls, AnalysisBase)
-                                    and cls != AnalysisBase
-                                ):
-                                    setattr(cls, "location", "local")
-                                    setattr(
-                                        cls, "folder", base_path + [Path(script).stem]
-                                    )
-                                    functions.append(cls(conn))
-                        except ImportError:
-                            errors.append(("local", base_path, Path(script).stem))
-                else:
-                    import_scripts(val, base_path + [key])
+            def import_scripts(scripts, base_path=[]):
+                for key, val in scripts.items():
+                    if key == ".":
+                        for script in val:
+                            try:
+                                module = import_script(Path(folder) / script)
+                                for _, cls in module.__dict__.items():
+                                    if (
+                                        inspect.isclass(cls)
+                                        and issubclass(cls, AnalysisBase)
+                                        and cls != AnalysisBase
+                                    ):
+                                        setattr(cls, "location", "local")
+                                        setattr(
+                                            cls, "folder", base_path + [Path(script).stem]
+                                        )
+                                        functions.append(cls(conn))
+                            except ImportError:
+                                errors.append(("local", base_path, Path(script).stem))
+                    else:
+                        import_scripts(val, base_path + [key])
 
-        import_scripts(scripts)
+            import_scripts(scripts)
 
     # github analysis functions
     github_repos = get_config()["github"]
@@ -132,10 +134,16 @@ def import_analysis(conn, tables):
                 repo_path = tmp_path / name
                 if repo_path.exists():
                     repo = git.Repo(repo_path)
-                    repo.remotes.origin.pull()
+                    # Access the 'origin' remote explicitly
+                    origin = repo.remotes["origin"] if "origin" in repo.remotes else None
+                    if origin:
+                        origin.pull()
+                    else:
+                        print(f"No 'origin' remote found for repository {name}")
                 else:
                     repo = git.Repo.clone_from(repo, repo_path)
-            except Exception:
+            except Exception as e:
+                print(e)
                 errors.append(("github", name, "Unknown error"))
                 continue
         elif status == "private":
@@ -349,37 +357,40 @@ def reload_analysis(conn, tables):
                 functions.append(cls(conn))
 
     # user-defined analysis functions
-    user_analysis = get_config()["analysis"]["folders"]
-    for folder in user_analysis:
-        scripts = find_script_in_subfolders(folder)
+    config = get_config()
+    deployment = config.get("deployment", {}).get("deployment")
+    if deployment == "local" or (deployment == "apptainer" and "analysis" in config):
+        user_analysis = config["analysis"]["folders"]
+        for folder in user_analysis:
+            scripts = find_script_in_subfolders(folder)
 
-        def import_scripts(scripts, base_path=[]):
-            for key, val in scripts.items():
-                if key == ".":
-                    for script in val:
-                        try:
-                            module_name = Path(script).stem
-                            if module_name in sys.modules:
-                                module = importlib.reload(sys.modules[module_name])
-                            else:
-                                module = import_script(Path(folder) / script)
-                            for _, cls in module.__dict__.items():
-                                if (
-                                    inspect.isclass(cls)
-                                    and issubclass(cls, AnalysisBase)
-                                    and cls != AnalysisBase
-                                ):
-                                    setattr(cls, "location", "local")
-                                    setattr(
-                                        cls, "folder", base_path + [Path(script).stem]
-                                    )
-                                    functions.append(cls(conn))
-                        except ImportError:
-                            errors.append(("local", base_path, Path(script).stem))
-                else:
-                    import_scripts(val, base_path + [key])
+            def import_scripts(scripts, base_path=[]):
+                for key, val in scripts.items():
+                    if key == ".":
+                        for script in val:
+                            try:
+                                module_name = Path(script).stem
+                                if module_name in sys.modules:
+                                    module = importlib.reload(sys.modules[module_name])
+                                else:
+                                    module = import_script(Path(folder) / script)
+                                for _, cls in module.__dict__.items():
+                                    if (
+                                        inspect.isclass(cls)
+                                        and issubclass(cls, AnalysisBase)
+                                        and cls != AnalysisBase
+                                    ):
+                                        setattr(cls, "location", "local")
+                                        setattr(
+                                            cls, "folder", base_path + [Path(script).stem]
+                                        )
+                                        functions.append(cls(conn))
+                            except ImportError:
+                                errors.append(("local", base_path, Path(script).stem))
+                    else:
+                        import_scripts(val, base_path + [key])
 
-        import_scripts(scripts)
+            import_scripts(scripts)
 
     # github analysis functions
     github_repos = get_config()["github"]
@@ -393,7 +404,12 @@ def reload_analysis(conn, tables):
                 repo_path = tmp_path / name
                 if repo_path.exists():
                     repo = git.Repo(repo_path)
-                    repo.remotes.origin.pull()
+                    # Access the 'origin' remote explicitly
+                    origin = repo.remotes["origin"] if "origin" in repo.remotes else None
+                    if origin:
+                        origin.pull()
+                    else:
+                        print(f"No 'origin' remote found for repository {name}")
                 else:
                     repo = git.Repo.clone_from(repo, repo_path)
             except Exception:
