@@ -24,6 +24,7 @@ import inspect
 import traceback
 import os
 from uuid import uuid4
+import streamlit as st
 
 """
 It's important to mention how our naming conventions work for animals.
@@ -185,7 +186,6 @@ def insert_features(primary_key, rig_json):
         insert_feature["data_type"] = feature["data_type"]
         insert_feature["feature_description"] = feature["description"]
         insert_feature["feature_data"] = None
-        insert_feature["feature_deleted"] = "False"
 
         # append to list
         feature_list.append(insert_feature)
@@ -310,7 +310,7 @@ def insert_nwb(world, selfs, nwbpath, username=None, password=None):
         None
     """
 
-    conn_insert, tables_insert = connect(username, password)
+    conn_insert, tables_insert = thread_connect(username=username, password=password)
 
     # pull the features from the database
     rig_json = (tables_insert["BehaviourRig"] & world).fetch1("rig_json")
@@ -558,7 +558,7 @@ def insert_nwb(world, selfs, nwbpath, username=None, password=None):
 
 
 def recompute_masks(restriction, username=None, password=None):
-    conn_insert, tables_insert = connect(username, password)
+    conn_insert, tables_insert = thread_connect(username=username, password=password)
 
     # pull the world from the database
     worlds = (tables_insert["World"] & restriction).proj().fetch(as_dict=True)
@@ -665,7 +665,7 @@ def create_dlc_folder(key, username=None, password=None):
     Otherwise, it deletes the DLC folder, downloads the remaining videos, makes the DLC folder and returns the config path.
     """
 
-    conn_dlc, tables_dlc = thread_connect(username, password)
+    conn_dlc, tables_dlc = thread_connect(username=username, password=password)
 
     name = f"{key['experimenter']}_{key['behaviourrig_id']}_{key['experiment_id']}_{key['dlcmodel_id']}"
     tmpdir = Path(tempfile.gettempdir())
@@ -739,7 +739,7 @@ def upload_dlc(key, username=None, password=None):
     Function zips the labelled frames folder and uploads to the database along with the config json
     """
 
-    conn_dlc, tables_dlc = thread_connect(username, password)
+    conn_dlc, tables_dlc = thread_connect(username=username, password=password)
 
     name = f"{key['experimenter']}_{key['behaviourrig_id']}_{key['experiment_id']}_{key['dlcmodel_id']}"
     conf = st.session_state.dlc_folder[name]
@@ -762,10 +762,16 @@ def upload_dlc(key, username=None, password=None):
     key["dlcparams"] = params_dict
     key["labelled_frames"] = str(labeled_zip)
     key["labelledframes_in_compute"] = "False"
-    key["labelledframes_deleted"] = "False"
-    del key["behaviourrig_deleted"]
 
-    tables_dlc["LabelledFrames"].insert1(key, allow_direct_insert=True)
+    primary_key = {key:val for key, val in key.items() if key in ["experimenter", "behaviourrig_id", "experiment_id", "dlcmodel_id"]}
+    print(key)
+
+    if len(tables_dlc["LabelledFrames"]._admin() & primary_key) == 0:
+        tables_dlc["LabelledFrames"].insert1(key, allow_direct_insert=True)
+    else:
+        # if it already exists, delete the old one
+        tables_dlc["LabelledFrames"].delete(primary_key, force=True)
+        tables_dlc["LabelledFrames"].insert1(key, allow_direct_insert=True, skip_duplicates=True)
 
 
 def select_masks(tables):
@@ -815,7 +821,6 @@ def insert_masks(key, masks, id, tables):
         inplace=True,
     )
     df["mask_id"] = range(id, id + len(df))
-    df["maskfunction_deleted"] = "False"
 
     new_serialise = partial(serialise_function, tables=tables)
     df["mask_function"] = df["function"].apply(new_serialise)
