@@ -249,40 +249,11 @@ def query_without_external(query, mode="Sequential Filter"):
 
     # calculate any external attributes to be removed (so it doesn't download)
     # also calculate any jsons to be removed (since they look messy)
-    projection = []
-    external = []
-    jsons = []
-    blobs = []
-    for key, val in query.heading.attributes.items():
-        if val.is_attachment:
-            external.append(key)
-        elif val.json:
-            jsons.append(key)
-        elif val.is_blob:
-            blobs.append(key)
-        else:
-            projection.append(key)
 
-    # remove external attributes and deleted
-    query = query.proj(*projection)
-
-    # fetch query
-    df = query.fetch(format="frame", limit=30)
-
-    # reset index (so we can hide it later)
-    df = df.reset_index()
-
-    # replace json entries
-    for i in jsons:
-        df[i] = len(df.index) * ["json"]
-
-    # replace blobs entries
-    for i in blobs:
-        df[i] = len(df.index) * ["blob"]
-
-    # add blank external entries for display
-    for i in external:
-        df[i] = len(df.index) * ["external"]
+    if mode == "Sequential Filter":
+        df = query.display(show='name')
+    elif mode == "Navigation":
+        df = query.display(show='id')
 
     return df, len(query)
 
@@ -370,9 +341,25 @@ def check_session(tables, insert_dict):
 
     # check all files exist
     for ext in equip_ext:
-        status = len(list(insert_dict["recording"].glob(f"*.{ext}"))) > 0
+        if ext == "dir":
+            # check if the folder contains a directory
+            status = any(item.is_dir() for item in insert_dict["recording"].iterdir())
+        else:
+            status = len(list(insert_dict["recording"].glob(f"*.{ext}"))) > 0
         checkls.append(status)
 
+    # check channel mapping
+    if 'device_channel_mapping' in insert_dict.keys():
+        if not Path(insert_dict['device_channel_mapping']).exists():
+            return False
+        else:
+            with open(insert_dict['device_channel_mapping']) as f:
+                device_channel_mapping = json.load(f)
+                if not type(device_channel_mapping) == list:
+                    return False
+                if not all([isinstance(i, int) for i in device_channel_mapping]):
+                    return False
+
     # return true if all files exist
     return all(checkls)
 
@@ -408,14 +395,6 @@ def upload(
         dirpath = insert_dict["recording"]
 
         # create zipfile name from primary key
-        """
-        # old filepath
-        filename = (
-            "-".join([str(list(insert_dict.values())[i]) for i in range(4)]) + ".zip"
-        )
-        recfile = Path(tempfile.gettempdir()) / "antelop_raw" / Path(filename)
-        recfile.parent.mkdir(parents=True, exist_ok=True)
-        """
         recfile = Path(dirpath).with_suffix(".zip")
 
         # get files to zip
@@ -424,16 +403,35 @@ def upload(
         equip_ext = extensions[ephys_acquisition]
         files = []
         for ext in equip_ext:
-            files.extend(list(Path(dirpath).glob(f"*.{ext}")))
+            if ext == "dir":
+                # add all directories
+                files.extend([item for item in Path(dirpath).iterdir() if item.is_dir()])
+            else:
+                files.extend(list(Path(dirpath).glob(f"*.{ext}")))
 
         # create zipfile
         with zipfile.ZipFile(recfile, "w") as zipf:
             for file in files:
-                zipf.write(Path(dirpath) / file, arcname=file.name)
+                if file.is_dir():
+                    # Recursively add all files in the directory
+                    for root, _, filenames in os.walk(file):
+                        for filename in filenames:
+                            filepath = Path(root) / filename
+                            arcname = filepath.relative_to(dirpath)  # Preserve relative path
+                            zipf.write(filepath, arcname=arcname)
+                else:
+                    # Add individual files
+                    zipf.write(file, arcname=file.name)
 
         # update dirpath
         insert_dict["recording"] = str(recfile)
 
+        if 'device_channel_mapping' in insert_dict.keys():
+            with open(insert_dict['device_channel_mapping']) as f:
+                device_channel_mapping = json.load(f)
+
+                insert_dict['device_channel_mapping'] = device_channel_mapping
+
     # start insert transaction
     with table_upload.connection.transaction:
         # insert data
@@ -517,7 +515,6 @@ def restore(querystring, username=None, password=None, conn=None):
 
     # form query
     query = form_query(querystring, tables_res, admin=True)
-    print(query.restriction)
     query = query & query.restriction
     query.restore()
 
@@ -569,10 +566,33 @@ def release_computation(
                 )
 
 
+def names_to_ids(keys, tables):
+    """
+    Functions converts a list of keys with name columns to id columns
+    input: keys: list of keys
+    return: list of keys with id columns
+    """
+    table_names = {table.table_name.replace('#','').replace('_',''):table for table in tables.values()}
+    new_keys = []
+    for key in keys:
+        new_key = {}
+        for k, v in key.items():
+            if "name" in k:
+                id_col = k.replace("name", "id")
+                table = table_names[k.replace("_name", "")]
+                tmp_key = {**new_key, k: v}
+                new_key[id_col] = (table & tmp_key).fetch1(k.replace("_name", "_id"))
+            else:
+                new_key[k] = v
+        new_keys.append(new_key)
+    return new_keys
+
+
 def show_deletes(tables, query):
     """
     Function to show all the deletes that cascade
     """
+    query = query.proj()
 
     # make dict mapping full_table_names to display table full_table_names
     full_names = {val.full_table_name: key for key, val in tables.items()}
@@ -582,10 +602,10 @@ def show_deletes(tables, query):
 
     # cycle through descendants calculating number that will get deleted
     for descendant in query.descendants():
-        table = tables[full_names[descendant]]
 
-        # main query
-        full_query = table & query.proj()
+        table = tables[full_names[descendant]]
+        # main new_query
+        full_query = table & query
 
         number_entries = len(full_query)
         if number_entries > 0:
@@ -734,3 +754,16 @@ class SimulateEnterContext:
         sys.stdin = self.original_stdin
         self.fake_input.close()
         sys.stdout = self.original_stdout
+
+
+def ids_to_names(cols):
+    """
+    Functions converts a list of table attributes with id columns to name columns
+    """
+    names = []
+    for col in cols:
+        if "id" in col:
+            names.append(col.replace("id", "name"))
+        else:
+            names.append(col)
+    return names
\ No newline at end of file
