@@ -83,7 +83,7 @@ def schedule_spikesorting(session_dict, username, password, numjobs):
     logdir = compute_log()
     logdirmnt = Path(config["computation"]["antelop_data"]) / "logs" / logdir
 
-    slurmtime = slurm_time(numjobs)
+    slurmtime = slurm_time(numjobs, scale=4)
 
     # command to be run
     command = (
@@ -321,7 +321,6 @@ def schedule_train_dlc(key, num_videos, password):
         k: (int(v) if k in ["experiment_id", "behaviourrig_id", "dlcmodel_id"] else v)
         for k, v in key.items()
     }
-    del key["labelledframes_deleted"]
 
     # make nextflow submission command
     param = json.dumps(key, separators=(",", ":"))
