@@ -19,6 +19,7 @@ from antelop.utils.datajoint_utils import (
     get_tablename,
     get_ephys_extensions,
 )
+import yaml
 from antelop.utils.os_utils import get_config
 from antelop.connection import import_schemas
 import pandas as pd
@@ -271,7 +272,6 @@ def input_sorter_params():
 
     return sorter_params
 
-
 def dropdown_query_table(
     tables,
     subtables,
@@ -570,6 +570,10 @@ def dropdown_insert_table(
         # inserted entries are not in a computation
         elif key == f"""{table.table_name.replace("_", "")}_in_compute""":
             insert_dict[key] = 0
+        
+        # duration is blank
+        elif key == "session_duration":
+            continue
 
         # leave if autoincrement
         elif table.heading.attributes[key].autoincrement:
@@ -703,9 +707,14 @@ def dropdown_insert_table(
 
         # if it's a json, upload file
         elif table.heading.attributes[key].json:
-            jsonfile = server_directory_browser(message="Select json", extension="json")
-            if jsonfile:
-                insert_dict[key] = jsonfile
+            if table.heading.attributes[key].nullable:
+                add_json = st.checkbox(f"Add {key} json?")
+            else:
+                add_json = True
+            if add_json:
+                jsonfile = server_directory_browser(message=f"Select {key} json", extension="json")
+                if jsonfile:
+                    insert_dict[key] = jsonfile
 
         # if it's a notes box, print a bigger box
         elif key[-5:] == "notes":
@@ -1299,7 +1308,7 @@ def children_buttons(query, tables):
     full_names = {val.full_table_name: key for key, val in tables.items()}
 
     # query projected table
-    df, number = query_without_external(query.proj())
+    df, number = query_without_external(query.proj(), mode='Navigation')
     columns = list(df.columns)
 
     # add checkboxes for each child
