@@ -14,32 +14,6 @@ from pathlib import Path
 import os
 
 
-@st.cache_data(ttl=3600)
-def session_length(session_dict):
-    # open database connection for main thread
-    conn = connect.connect()
-
-    # import schema structure
-    tables = import_schemas.schema(conn)
-
-    # loop through all the data
-    max_time = 0
-    units = (tables["SpikeTrain"] & session_dict).fetch(as_dict=True)
-    for unit in units:
-        max_time = max(max_time, np.max(unit["spiketrain"], initial=0))
-    analog_events = (tables["AnalogEvents"] & session_dict).fetch(as_dict=True)
-    for event in analog_events:
-        max_time = max(max_time, np.max(event["timestamps"], initial=0))
-    digital_events = (tables["DigitalEvents"] & session_dict).fetch(as_dict=True)
-    for event in digital_events:
-        max_time = max(max_time, np.max(event["timestamps"], initial=0))
-    interval_events = (tables["IntervalEvents"] & session_dict).fetch(as_dict=True)
-    for event in interval_events:
-        max_time = max(max_time, np.max(event["timestamps"], initial=0))
-
-    return max_time
-
-
 @st.cache_data(ttl=3600, max_entries=3)
 def plot_session(session_dict, selected_animals, selected_objects, timerange):
     # unpack objects
@@ -51,11 +25,8 @@ def plot_session(session_dict, selected_animals, selected_objects, timerange):
         masks_objects,
     ) = selected_objects
 
-    # open database connection for main thread
-    conn = connect.connect()
-
-    # import schema structure
-    tables = import_schemas.schema(conn)
+    conn = st.session_state.conn
+    tables = st.session_state.tables
 
     # get spike trains for the selected animals and sorting parameters - requires a slight abuse of union
     query = False
@@ -517,11 +488,9 @@ def plot_session(session_dict, selected_animals, selected_objects, timerange):
 
 @st.cache_data(ttl=3600, max_entries=3)
 def plot_kinematics(kinematics_dict, timerange):
-    # open database connection for main thread
-    conn = connect.connect()
 
-    # import schema structure
-    tables = import_schemas.schema(conn)
+    conn = st.session_state.conn
+    tables = st.session_state.tables
 
     # pull data
     kinematics_events = (
@@ -929,11 +898,9 @@ def choose_objects(tables, session_dict):
 
 @st.cache_data(ttl=3600, max_entries=3)
 def plot_units(spikesorting_dict, selected_units):
-    # open database connection for main thread
-    conn = connect.connect()
 
-    # import schema structure
-    tables = import_schemas.schema(conn)
+    conn = st.session_state.conn
+    tables = st.session_state.tables
 
     # fetch waveform data
     waveforms = (tables["Waveform"] & spikesorting_dict & selected_units).fetch()
@@ -945,71 +912,66 @@ def plot_units(spikesorting_dict, selected_units):
     for probe in probes:
         # get unique channels for this probe
         channels = np.unique(waveforms[waveforms["probe_id"] == probe]["channel_id"])
+        figures[int(probe)] = {}
 
-        # make subplots
-        fig = make_subplots(
-            rows=(len(channels) + 1) // 2,
-            cols=2,
-            shared_xaxes=True,
-            vertical_spacing=0.1,
-            subplot_titles=[f"Channel {channel}" for channel in channels],
-        )
+        # split channels into groups of 4 (2x2 layout)
+        channel_groups = [channels[i:i + 4] for i in range(0, len(channels), 4)]
 
-        # loop through channels
-        for i, channel in enumerate(channels):
-            # get units for this channel
-            units = waveforms[
-                (waveforms["probe_id"] == probe) & (waveforms["channel_id"] == channel)
-            ]
-
-            # plot units
-            for j, unit in enumerate(units):
-                waveform = np.median(unit["waveform"], axis=0)
-                q1 = np.percentile(unit["waveform"], 25, axis=0)
-                q3 = np.percentile(unit["waveform"], 75, axis=0)
-                q1 = waveform + 10
-                q3 = waveform - 10
-                timestamps = (
-                    np.arange(waveform.shape[0]) / (unit["waveform_sample_rate"] / 1000)
-                ) - unit["ms_before"]
-
-                color = px.colors.qualitative.Plotly[
-                    j % len(px.colors.qualitative.Plotly)
-                ]
-                fade = 1
-                r, g, b = (
-                    str(int(fade * int(color[1:3], 16))),
-                    str(int(fade * int(color[3:5], 16))),
-                    str(int(fade * int(color[5:7], 16))),
-                )
-
-                fig.add_trace(
-                    go.Scattergl(
-                        x=timestamps,
-                        y=waveform,
-                        mode="lines",
-                        name=f"Unit {unit['unit_id']}",
-                        legendgroup=f"Unit {unit['unit_id']}",
-                        line=dict(color=color),
-                        showlegend=True if i == 0 else False,
-                    ),  # in the future this will need to be changed if we have sparse extraction
-                    row=(i // 2) + 1,
-                    col=(i % 2) + 1,
-                )
-
-            fig.update_yaxes(
-                title_text="Voltage (uV)", row=(i // 2) + 1, col=(i % 2) + 1
+        for group_idx, group_channels in enumerate(channel_groups):
+            # make subplots
+            num_rows = (len(group_channels) + 1) // 2  # Max 2 rows
+            fig = make_subplots(
+                rows=num_rows,
+                cols=2,
+                shared_xaxes=True,
+                vertical_spacing=0.1,
+                subplot_titles=[f"Channel {channel}" for channel in group_channels],
             )
-            if i // 2 + 1 == len(channels) // 2:
-                fig.update_xaxes(
-                    title_text="Time (ms)", row=(i // 2) + 1, col=(i % 2) + 1
-                )
 
-        fig.update_layout(
-            title=f"Probe {probe} waveforms", showlegend=True, width=800, height=800
-        )
+            # loop through channels in the group
+            for i, channel in enumerate(group_channels):
+                # get units for this channel
+                units = waveforms[
+                    (waveforms["probe_id"] == probe) & (waveforms["channel_id"] == channel)
+                ]
 
-        figures[int(probe)] = fig
+                # plot units
+                for j, unit in enumerate(units):
+                    waveform = np.median(unit["waveform"], axis=0)
+                    timestamps = (
+                        np.arange(waveform.shape[0]) / (unit["waveform_sample_rate"] / 1000)
+                    ) - unit["ms_before"]
+
+                    color = px.colors.qualitative.Plotly[
+                        j % len(px.colors.qualitative.Plotly)
+                    ]
+
+                    fig.add_trace(
+                        go.Scattergl(
+                            x=timestamps,
+                            y=waveform,
+                            mode="lines",
+                            name=f"Unit {unit['unit_id']}",
+                            legendgroup=f"Unit {unit['unit_id']}",
+                            line=dict(color=color),
+                            showlegend=True if i == 0 else False,
+                        ),
+                        row=(i // 2) + 1,
+                        col=(i % 2) + 1,
+                    )
+
+                fig.update_yaxes(title_text="Voltage (uV)", row=(i // 2) + 1, col=(i % 2) + 1)
+                if (i // 2) + 1 == num_rows:
+                    fig.update_xaxes(title_text="Time (ms)", row=(i // 2) + 1, col=(i % 2) + 1)
+
+            fig.update_layout(
+                title=f"Probe {probe} - Group {group_idx + 1} waveforms",
+                showlegend=True,
+                width=800,
+                height=400 * num_rows,
+            )
+
+            figures[int(probe)][f"Group {group_idx + 1}"] = fig
 
     return figures
 
@@ -1020,11 +982,8 @@ def plot_isi(spikesorting_dict, selected_units):
     Plot the isi of the selected units
     """
 
-    # open database connection for main thread
-    conn = connect.connect()
-
-    # import schema structure
-    tables = import_schemas.schema(conn)
+    conn = st.session_state.conn
+    tables = st.session_state.tables
 
     # fetch spiketrains
     spiketrains = (tables["SpikeTrain"] & spikesorting_dict & selected_units).fetch()
@@ -1100,11 +1059,8 @@ def unit_stats(spikesorting_dict, selected_units):
     Computes some statistics for each unit
     """
 
-    # open database connection for main thread
-    conn = connect.connect()
-
-    # import schema structure
-    tables = import_schemas.schema(conn)
+    conn = st.session_state.conn
+    tables = st.session_state.tables
 
     # fetch spiketrains
     spiketrains = (tables["SpikeTrain"] & spikesorting_dict & selected_units).fetch()
@@ -1116,7 +1072,7 @@ def unit_stats(spikesorting_dict, selected_units):
     for probe in probes:
         data = []
 
-        T = session_length(spikesorting_dict)
+        T = (tables['Session'] & spikesorting_dict).fetch1('session_duration')
 
         # get unique channels for this probe
         units = np.unique(spiketrains[spiketrains["probe_id"] == probe]["unit_id"])
